@@ -30,18 +30,19 @@
 #include <QAction>
 #include <KActionCollection>
 #include <KConfig>
-#include <KIcon>
+#include <QIcon>
 #include <KIconLoader>
 #include <KRun>
 #include <KAboutData>
 #include <KHTMLView>
 #include <KHTMLSettings>
 #include <KStandardShortcut>
-#include <KDialog>
+#include <QDialog>
 #include <KStandardAction>
 #include <KXmlGuiWindow>
 #include <KStartupInfo>
 #include <KConfigGroup>
+#include <KWindowConfig>
 
 #include <QtDBus/QDBusConnection>
 #include <QSplitter>
@@ -56,22 +57,32 @@
 #include <QStatusBar>
 
 #include <stdlib.h>
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 QLoggingCategory category("org.kde.khelpcenter");
 
 using namespace KHC;
 
-class LogDialog : public KDialog
+class LogDialog : public QDialog
 {
   public:
     LogDialog( QWidget *parent = 0 )
-      : KDialog( parent )
+      : QDialog( parent )
     {
-      setCaption( i18n("Search Error Log") );
-      setButtons( Ok );
+      setWindowTitle( i18n("Search Error Log") );
+      QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
+      QVBoxLayout *mainLayout = new QVBoxLayout;
+      setLayout(mainLayout);
+      QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+      okButton->setDefault(true);
+      okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+      connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+      connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
       QFrame *topFrame = new QFrame( this );
-      setMainWidget( topFrame );
+      mainLayout->addWidget(topFrame);
+      mainLayout->addWidget(buttonBox);
 
       QBoxLayout *topLayout = new QVBoxLayout( topFrame );
 
@@ -79,15 +90,16 @@ class LogDialog : public KDialog
       mTextView->setReadOnly ( true );
       mTextView->setWordWrapMode( QTextOption::NoWrap );
       topLayout->addWidget( mTextView );
+      
 
       KConfigGroup cg = KSharedConfig::openConfig()->group( "logdialog" );
-      restoreDialogSize( cg );
+      KWindowConfig::restoreWindowSize( windowHandle(), cg );
     }
 
     ~LogDialog()
     {
       KConfigGroup cg = KSharedConfig::openConfig()->group( "logdialog" );
-      KDialog::saveDialogSize( cg );
+      KWindowConfig::saveWindowSize(windowHandle(), cg);
     }
 
     void setLog( const QString &log )
@@ -111,7 +123,7 @@ MainWindow::MainWindow()
 
     mDoc = new View( mSplitter, this, KHTMLPart::DefaultGUI, actionCollection() );
     connect( mDoc, SIGNAL( setWindowCaption( const QString & ) ),
-             SLOT( setCaption( const QString & ) ) );
+             SLOT( setWindowTitle( const QString & ) ) );
     connect( mDoc, SIGNAL( setStatusBarText( const QString & ) ),
              SLOT( statusBarMessage( const QString & ) ) );
     connect( mDoc, SIGNAL( onURL( const QString & ) ),
@@ -217,7 +229,7 @@ void MainWindow::writeConfig()
 
     mNavigator->writeConfig();
 
-    Prefs::self()->writeConfig();
+    Prefs::self()->save();
 }
 
 void MainWindow::setupActions()
@@ -227,13 +239,13 @@ void MainWindow::setupActions()
 
     QAction *prevPage  = actionCollection()->addAction( "prevPage" );
     prevPage->setText( i18n( "Previous Page" ) );
-    prevPage->setShortcut( Qt::CTRL+Qt::Key_PageUp );
+    actionCollection()->setDefaultShortcut(prevPage, Qt::CTRL+Qt::Key_PageUp );
     prevPage->setWhatsThis( i18n( "Moves to the previous page of the document" ) );
     connect( prevPage, SIGNAL( triggered() ), mDoc, SLOT( prevPage() ) );
 
     QAction *nextPage  = actionCollection()->addAction( "nextPage" );
     nextPage->setText( i18n( "Next Page" ) );
-    nextPage->setShortcut( Qt::CTRL + Qt::Key_PageDown );
+    actionCollection()->setDefaultShortcut(nextPage, Qt::CTRL + Qt::Key_PageDown );
     nextPage->setWhatsThis( i18n( "Moves to the next page of the document" ) );
     connect( nextPage, SIGNAL( triggered() ), mDoc, SLOT( nextPage() ) );
 
@@ -270,12 +282,12 @@ void MainWindow::setupActions()
 
     action = actionCollection()->addAction(QLatin1String("incFontSizes"));
     action->setText( i18n( "Increase Font Sizes" ) );
-    action->setIcon( KIcon( QLatin1String("zoom-in") ) );
+    action->setIcon( QIcon::fromTheme( QLatin1String("zoom-in") ) );
     connect( action, SIGNAL( triggered() ), this, SLOT( slotIncFontSizes() ) );
 
     action = actionCollection()->addAction(QLatin1String("decFontSizes"));
     action->setText( i18n( "Decrease Font Sizes" ) );
-    action->setIcon( KIcon( QLatin1String("zoom-out") ) );
+    action->setIcon( QIcon::fromTheme( QLatin1String("zoom-out") ) );
     connect( action, SIGNAL( triggered() ), this, SLOT( slotDecFontSizes() ) );
 }
 
@@ -493,6 +505,5 @@ void MainWindow::slotConfigureFonts()
   }
 }
 
-#include "mainwindow.moc"
 
 // vim:ts=2:sw=2:et
